defmodule DerivantesWeb.UserLoginLive do
  use DerivantesWeb, :live_view

  def render(assigns) do
    ~H"""
    <div class="login-container">
      <div class="login-a">
        <.simple_form
          for={@form}
          id="login_form"
          action={~p"/derivantes/log_in"}
          phx-update="ignore"
          class="auth_form"
        >
        <img src={~p"/images/sana_americano_logo.png"} alt="Sanatorio Americano Logo"/>
          <.input
            field={@form[:email]}
            type="email"
            label=""
            class="imput_text"
            placeholder="Email"
            required
          />
          <.input
            field={@form[:password]}
            type="password"
            label=""
            class="imput_text"
            placeholder="Contraseña"
            required
          />

          <:actions>
            <.input field={@form[:remember_me]} type="checkbox" label="Mantenerme conectado" class="accent-[#297177]"/>
            <.link href={~p"/derivantes/reset_password"} class="text-sm text-white font-semibold">
              ¿Olvidó su contraseña?
            </.link>
          </:actions>
          <:actions>
            <.button phx-disable-with="Ingresando..." class="w-full submit_button">
              Ingresar <span aria-hidden="true">→</span>
            </.button>
          </:actions>
        </.simple_form>

        <.header class="text-center">
          Ingrese a su cuenta
          <:subtitle>
            ¿No tiene una? <br>
            <.link navigate={~p"/derivantes/register"} class="font-semibold text-[#297177] hover:underline">
              Registre y active
            </.link>
            su cuenta ahora.
          </:subtitle>
        </.header>

      </div>

      <div class="welcome_text">
        <p style="text-align: center;">Bienvenido a Entrega Digital <br><b>Sanatorio Americano.</b></p><br>
        <p>En este sitio, usted podrá visualizar los informes y estudios realizados en nuestra institución.</p><br>
        <p>Si presenta inconvenientes con los datos ingresados, puede comunicarse con nosotros enviando un correo a <b>mesadeayuda@sanatorio-americano.com.ar</b> detallando su nombre completo y D.N.I.</p>
      </div>
    </div>
    """
  end

  def mount(_params, _session, socket) do
    email = Phoenix.Flash.get(socket.assigns.flash, :email)
    form = to_form(%{"email" => email}, as: "user")
    {:ok, assign(socket, form: form), temporary_assigns: [form: form]}
  end
end
